History
=======

0.2.0 (2018-07-25)
------------------

Bug Fixes
~~~~~~~~~

* changelog - Fix release markup being inserted in the wrong place

Features
~~~~~~~~

* release

  - Show useful info while running release subcommand
  - Add support to custom change log file names
  - Support version string update on selected files
* init - Add interactive config and changelog files creation

0.1.0 (2018-07-13)
------------------

Features
~~~~~~~~

* release

  - Add --no-commit and --no-tag options
  - Add options for manual version bump

